@@ -4,13 +4,14 @@ use strict;
 use warnings;
 
 use Mo qw(build default is);
-use Mo::utils 0.28 qw(check_array_object check_length check_number_id check_strings);
+use Mo::utils 0.21 qw(check_array_object check_length check_strings);
+use Mo::utils::Number qw(check_positive_natural);
 use Mo::utils::Email qw(check_email);
 use Readonly;
 
 Readonly::Array our @SEX => qw(female male unknown);
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 has email => (
 	is => 'ro',
@@ -43,7 +44,7 @@ sub BUILD {
 	check_array_object($self, 'external_ids', 'Data::ExternalId', 'External id');
 
 	# Check id.
-	check_number_id($self, 'id');
+	check_positive_natural($self, 'id');
 
 	# Check name.
 	check_length($self, 'name', 255);
@@ -77,6 +78,10 @@ Data::Person - Data object for person.
  my $name = $obj->name;
  my $sex = $obj->sex;
 
+=head1 DESCRIPTION
+
+The immutable data object for representation of person.
+
 =head1 METHODS
 
 =head2 C<new>
@@ -173,8 +178,8 @@ Returns string.
                  External id isn't 'Data::ExternalId' object.
                          Value: %s
                          Reference: %s
-         From Mo::utils::check_number_id():
-                 Parameter 'id' must a natural number.
+         From Mo::utils::Number::check_positive_natural():
+                 Parameter 'id' must a positive natural number.
                          Value: %s
          Parameter 'name' has length greater than '255'.
                  Value: %s
@@ -228,6 +233,7 @@ Returns string.
 L<Mo>,
 L<Mo::utils>,
 L<Mo::utils::Email>,
+L<Mo::utils::Number>,
 L<Readonly>.
 
 =head1 REPOSITORY
@@ -248,6 +254,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
